@@ -1,10 +1,22 @@
-"""Classes used to build a schema.
+# copyright 2004-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of yams.
+#
+# yams is free software: you can redistribute it and/or modify it under the
+# terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option)
+# any later version.
+#
+# yams is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
+# A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with yams. If not, see <http://www.gnu.org/licenses/>.
+"""Classes used to build a schema."""
 
-:organization: Logilab
-:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: Lesser General Public License version 2 - http://www.gnu.org/licenses
-"""
 __docformat__ = "restructuredtext en"
 
 from warnings import warn
@@ -94,12 +106,12 @@ def register_base_types(schema):
 
 # XXX use a "frozendict"
 DEFAULT_RELPERMS = {'read': ('managers', 'users', 'guests',),
-                     'delete': ('managers', 'users'),
-                     'add': ('managers', 'users',)}
+                    'delete': ('managers', 'users'),
+                    'add': ('managers', 'users',)}
 
 DEFAULT_ATTRPERMS = {'read': ('managers', 'users', 'guests',),
-                      'update': ('managers', 'owners'),
-                      }
+                     'update': ('managers', 'owners'),
+                     }
 
 class Relation(object):
     """Abstract class which have to be defined before the metadefinition
@@ -492,7 +504,7 @@ class RelationDefinition(Definition):
 
         register all relations definition, expanding wildcard if necessary
         """
-        assert cls.subject and cls.object, '%s; check the schema' % cls
+        assert cls.subject and cls.object, '%s; check the schema (%s, %s)' % (cls, cls.subject, cls.object)
         cls()._add_relations(defined, schema)
 
     def _add_relations(self, defined, schema):
