@@ -1,9 +1,22 @@
+# copyright 2004-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of yams.
+#
+# yams is free software: you can redistribute it and/or modify it under the
+# terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option)
+# any later version.
+#
+# yams is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
+# A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with yams. If not, see <http://www.gnu.org/licenses/>.
 """Some common constraint classes.
 
-:organization: Logilab
-:copyright: 2004-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: Lesser General Public License version 2 - http://www.gnu.org/licenses
 """
 
 __docformat__ = "restructuredtext en"
@@ -233,6 +246,7 @@ class BoundaryConstraint(BaseConstraint):
         return cls(op, eval(boundary))
 
 BoundConstraint = class_renamed('BoundConstraint', BoundaryConstraint)
+BoundConstraint.type = lambda x: 'BoundaryConstraint'
 
 
 class IntervalBoundConstraint(BaseConstraint):
