@@ -1,6 +1,22 @@
-from yams.buildobjs import (EntityType, SubjectRelation, ObjectRelation,
-                            String, Int, Float, Date, Boolean,
-                            RelationDefinition, RelationType)
+# copyright 2004-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of yams.
+#
+# yams is free software: you can redistribute it and/or modify it under the
+# terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option)
+# any later version.
+#
+# yams is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
+# A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with yams. If not, see <http://www.gnu.org/licenses/>.
+from yams.buildobjs import (EntityType, RelationDefinition, RelationType,
+                            SubjectRelation, String, Int, Float, Date, Boolean)
 
 class Affaire(EntityType):
     sujet = String(maxsize=128)
@@ -10,7 +26,10 @@ class Affaire(EntityType):
     obj_wildcard = SubjectRelation('*')
     sym_rel = SubjectRelation('Person', symmetric=True)
     inline_rel = SubjectRelation('Person', inlined=True, cardinality='?*')
-    subj_wildcard = ObjectRelation('*')
+
+class subj_wildcard(RelationDefinition):
+    subject = '*'
+    object = 'Affaire'
 
 
 class Person(EntityType):
